News
====

0.2
---

*Release date: 10-Nov-2010*

* FIX The generator delegate was not correctly alphabetizing the source list
* FIX Some documentation spelling mistakes

0.1
---

*Release date: 30-Sep-2010*

* Initial release
